The Net::Z3950::ZOOM, ZOOM and Net::Z3950 modules

This distribution contains three Perl modules for the price of one. They all provide facilities for building information retrieval clients using the standard Z39.50 and SRW/U protocols, but do so using different APIs.

INSTALLATION

To install this module, type the following:

perl Makefile.PL
make
make test
make install

DEBIAN PACKAGES

To build Debian packages, do:

dh-make-perl --build

DEPENDENCIES

This module requires these other modules and libraries:

SOURCE CODE

https://github.com/indexdata/zoom-perl

Copyright (C) 2005-2017 by Index Data.

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself, either Perl version 5.8.4 or, at your option, any later version of Perl 5 you may have available.